import json
import os

# Check if File Exists
def ifFileExists(filePath) -> bool:
    return os.path.exists(filePath)


# JSONConfigParser Class - for JSON Files
class JSONConfigParser:

    # init method to initialize JSONConfigParser 
    # with file path when an object is created.

    def __init__(self, configFilePath) -> None:
        if ifFileExists(configFilePath):
            self.configFilePath = configFilePath
            self.configurations = {}
            with open(self.configFilePath, "r") as configFileObject:
                self.configurations = json.load(configFileObject)
        else:
            raise FileNotFoundError("Configuration file - {0} , not found.".format(configFilePath)) 

    def getConfigurations(self) -> dict:
        return self.configurations


# JSONConfigParser - JSON config Parser Object
from configPy.jsonConfigParser import JSONConfigParser

# TXTConfigParser - TXT config Parser Object
from configPy.txtConfigParser import TXTConfigParser


from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='configParsePy',
    version='0.0.8',
    author='Tanmoy Sen Gupta',
    author_email='tanmoysps@gmail.com',
    url='https://github.com/TanmoySG/configPy',
    description='A tiny Configuration File Parser for Python Projects. Currently Supports JSON files only.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    license='MIT',
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=find_packages(),
    keywords=['imports', 'configurations', 'python', 'project'],
    install_requires=[],
    zip_safe=False
)


import os

# Check if File Exists
def ifFileExists(filePath) -> bool:
    return os.path.exists(filePath)


# TXTConfigParser Class - for TXT Files
class TXTConfigParser:

    # init method to initialize TXTConfigParser 
    # with file path when an object is created.

    def __init__(self, configFilePath) -> None:
        self.configurations = {"file_type" : "TXT", "input" : configFilePath}

        # Usage Mechanism TBD 

        # Sample Code -

        # if ifFileExists(configFilePath):
        #     self.configFilePath = configFilePath
        #     self.configurations = {}
        #     with open(self.configFilePath, "r") as configFileObject:
        #         self.configurations = json.load(configFileObject)
        # else:
        #     raise FileNotFoundError("Configuration file - {0} , not found.".format(configFilePath)) 

    def getConfigurations(self) -> dict:
        return self.configurations